<?php

declare(strict_types=1);

namespace Drupal\sms\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\sms\Message\SmsMessageInterface as PlainSmsMessageInterface;

/**
 * Interface for SMS message entity.
 */
interface SmsMessageInterface extends ContentEntityInterface, PlainSmsMessageInterface {

  /**
   * Gets the entity who sent the SMS message.
   *
   * @return \Drupal\Core\Entity\EntityInterface|null
   *   The entity who sent the SMS message, or NULL if it is missing.
   */
  public function getSenderEntity(): ?EntityInterface;

  /**
   * Set the entity who sent the SMS message.
   *
   * @return $this
   *   Return SMS message for chaining.
   */
  public function setSenderEntity(EntityInterface $entity);

  /**
   * Gets the entity who will receive the SMS message.
   *
   * @return \Drupal\Core\Entity\EntityInterface|null
   *   The entity who will receive the SMS message, or NULL if it is missing.
   */
  public function getRecipientEntity(): ?EntityInterface;

  /**
   * Set the entity who will receive the SMS message.
   *
   * @return $this
   *   Return SMS message for chaining.
   */
  public function setRecipientEntity(EntityInterface $entity);

  /**
   * Get whether the SMS message is in the queue to be processed.
   */
  public function isQueued(): bool;

  /**
   * Get whether the SMS message is in the queue to be processed.
   *
   * @return $this
   *   Return SMS message for chaining.
   */
  public function setQueued(bool $is_queued);

  /**
   * Get the creation timestamp of the SMS message.
   */
  public function getCreatedTime(): int;

  /**
   * Get the time to send the SMS message.
   */
  public function getSendTime(): int;

  /**
   * Set the time to send the SMS message.
   *
   * @return $this
   *   Return SMS message for chaining.
   */
  public function setSendTime(int $send_time);

  /**
   * The time the SMS message was processed.
   *
   * This value does not indicate whether the message was sent, only that the
   * gateway accepted the request.
   *
   * @return int|null
   *   The timestamp when SMS message was processed, or NULL if not processed.
   */
  public function getProcessedTime(): ?int;

  /**
   * Set the time the SMS message was processed.
   *
   * @param int $processed
   *   The timestamp when SMS message was processed.
   *
   * @return $this
   *   Return SMS message for chaining.
   */
  public function setProcessedTime(int $processed);

}
